@@ -129,6 +129,7 @@ class PostingSubstatus(str, Enum):
         POSTING_TRANSFERRED_TO_COURIER_SERVICE: передаётся в службу доставки
         POSTING_DRIVER_PICK_UP: у водителя
         POSTING_NOT_IN_SORT_CENTER: не принято на сортировочном центре
+        SHIP_FAILED: неудачная отправка
     """
     POSTING_ACCEPTANCE_IN_PROGRESS = "posting_acceptance_in_progress"
     POSTING_IN_ARBITRATION = "posting_in_arbitration"
@@ -154,6 +155,7 @@ class PostingSubstatus(str, Enum):
     POSTING_TRANSFERRED_TO_COURIER_SERVICE = "posting_transferred_to_courier_service"
     POSTING_DRIVER_PICK_UP = "posting_driver_pick_up"
     POSTING_NOT_IN_SORT_CENTER = "posting_not_in_sort_center"
+    SHIP_FAILED = "ship_failed"
 
 
 class CancellationType(str, Enum):
@@ -177,6 +179,58 @@ class CancellationType(str, Enum):
     UNSPECIFIED = ""
 
 
+class CancellationReasonTypeId(str, Enum):
+    """Инициатор отмены отправления.
+
+    Attributes:
+        BUYER: покупатель
+        SELLER: продавец
+    """
+    BUYER = "buyer"
+    SELLER = "seller"
+
+
+class LabelFormingStatus(str, Enum):
+    """Статус формирования этикеток.
+
+    Attributes:
+        PENDING: задание в очереди
+        IN_PROGRESS: формируются
+        COMPLETED: файл с этикетками готов
+        ERROR: ошибка при создании файла
+        UNSPECIFIED: не определено
+    """
+    PENDING = "pending"
+    IN_PROGRESS = "in_progress"
+    COMPLETED = "completed"
+    ERROR = "error"
+    UNSPECIFIED = ""
+
+
+class LabelType(str, Enum):
+    """Типы этикеток.
+
+    Attributes:
+        BIG_LABEL: Обычная этикетка
+        SMALL_LABEL: Маленькая этикетка
+    """
+    BIG_LABEL = "big_label"
+    SMALL_LABEL = "small_label"
+
+
+class MarkType(str, Enum):
+    """Тип кода маркировки.
+
+    Attributes:
+        MANDATORY_MARK: обязательная маркировка «Честный ЗНАК»
+        JW_UIN: уникальный идентификационный номер (УИН) ювелирного изделия
+        IMEI: IMEI мобильного устройства
+    """
+    MANDATORY_MARK = "mandatory_mark"
+    JW_UIN = "jw_uin"
+    IMEI = "imei"
+
+
 class PaymentTypeGroupName(str, Enum):
     """Тип оплаты.
     OZON_CARD: Ozon Карта
@@ -217,6 +271,23 @@ class PrrOption(str, Enum):
     UNSPECIFIED = ""
 
 
+class PostingShipmentStatus(str, Enum):
+    """Статус проверки всех экземпляров отправления и доступности сборки.
+
+    Attributes:
+        SHIP_AVAILABLE: сборка доступна
+        SHIP_NOT_AVAILABLE: сборка недоступна
+        VALIDATION_IN_PROCESS: экземпляры на проверке
+        UPDATE_AVAILABLE: разрешено редактировать данные по экземплярам
+        UPDATE_NOT_AVAILABLE: запрещено редактировать данные по экземплярам
+    """
+    SHIP_AVAILABLE = "ship_available"
+    SHIP_NOT_AVAILABLE = "ship_not_available"
+    VALIDATION_IN_PROCESS = "validation_in_process"
+    UPDATE_AVAILABLE = "update_available"
+    UPDATE_NOT_AVAILABLE = "update_not_available"
+
+
 class TplIntegrationType(str, Enum):
     """Тип интеграции со службой доставки
 
