@@ -1,6 +1,8 @@
 from typing import Optional
 
-from pydantic import Field, field_validator, ConfigDict
+from ...infrastructure import logging
+
+from pydantic import Field, field_validator, ConfigDict, model_validator
 from pydantic_settings import BaseSettings
 
 class APIConfig(BaseSettings):
@@ -9,7 +11,6 @@ class APIConfig(BaseSettings):
     Attributes:
         client_id: Идентификатор клиента Ozon (опционально)
         api_key: Авторизационный ключ Ozon Seller API (опционально)
-        log_level: Уровень логирования (опционально)
         base_url: Базовый URL API Ozon (опционально)
         max_requests_per_second: Максимальное количество запросов в секунду (опционально, 50 по документации Ozon)
         cleanup_interval: Интервал очистки неиспользуемых ресурсов в секундах (опционально)
@@ -20,6 +21,16 @@ class APIConfig(BaseSettings):
         retry_min_wait: Минимальная задержка между повторами неудачных запросов в секундах (опционально)
         retry_max_wait: Максимальная задержка между повторами неудачных запросов в секундах (опционально)
 
+        log_level: Уровень логирования (опционально)
+        log_json: Выводить в JSON (опционально)
+        log_format: Формат лога (опционально)
+        log_use_async: True, чтобы включить асинхронный режим (опционально)
+        log_max_queue_size: Максимальный размер очереди (опционально, только для асинхронного режима)
+        log_dir: Адрес к дирректирии с логами (опционально)
+        log_file: Имя файла логов (опционально)
+        log_max_bytes: Максимальный размер файла логов в байтах (опционально)
+        log_backup_files_count: Кол-во файлов архивных логов, которые нужно хранить (опционально)
+
     Notes:
         Любой из атрибутов конфигурации можно задать в файле `.env`, расположенном в корне вашего проекта.
         Правило наименования параметров в `.env`: `префикс OZON_SELLER_ + имя параметра в верхнем регистре`.
@@ -35,10 +46,6 @@ class APIConfig(BaseSettings):
         default=None,
         description="Авторизационный ключ Ozon Seller API",
     )
-    log_level: Optional[str] = Field(
-        default="ERROR",
-        description="Уровень логирования."
-    )
     base_url: str = Field(
         default="https://api-seller.ozon.ru",
         description="Базовый URL API Ozon"
@@ -70,13 +77,13 @@ class APIConfig(BaseSettings):
         description="Таймаут запросов в секундах"
     )
     max_retries: int = Field(
-        default=3,
+        default=5,
         ge=0,
         le=10,
         description="Максимальное количество повторных попыток для неудачных запросов"
     )
     retry_min_wait: float = Field(
-        default=4.0,
+        default=2,
         gt=0,
         description="Минимальная задержка между повторами неудачных запросов в секундах"
     )
@@ -86,6 +93,45 @@ class APIConfig(BaseSettings):
         description="Максимальная задержка между повторами неудачных запросов в секундах"
     )
 
+    log_level: Optional[str] = Field(
+        'ERROR', pattern='^(DEBUG|INFO|WARNING|ERROR|CRITICAL)$',
+        description="Уровень логирования."
+    )
+
+    log_json: Optional[bool] = Field(
+        False, description="Выводить в JSON."
+    )
+    log_format: Optional[str] = Field(
+        '%(asctime)s - %(name)s - %(levelname)s - %(message)s', description="Формат лога."
+    )
+    log_use_async: Optional[bool] = Field(
+        True, description='True, чтобы включить асинхронное логирование.'
+    )
+    log_max_queue_size: Optional[int] = Field(
+        10000, description='Размер очереди (только для async mode).'
+    )
+    log_dir: Optional[str] = Field(
+        None, description="Путь к директории с логами."
+    )
+    log_file: Optional[str] = Field(
+        None, description="Название файла логов. Файловое логирование активируется предоставлением имени файла."
+    )
+    log_max_bytes: Optional[int] = Field(
+        10 * 1024 * 1024, description="Максимальный размер лога."
+    )
+    log_backup_files_count: Optional[int] = Field(
+        5, description="Кол-во архивных файлов."
+    )
+    logger: Optional[logging.Logger] = Field(
+        None, description="Корневой логер раздела seller. Поле заполняется системой."
+    )
+    @model_validator(mode="after")
+    def get_logger(self):
+        """Назначает корневой логер раздела для сессии, используется для логирования."""
+        if self.logger is None:
+            self.logger = logging.manager.get_logger("seller")
+        return self
+
     @field_validator("base_url")
     def validate_base_url(cls, v: str) -> str:
         """Валидация базового URL."""
