@@ -1,12 +1,11 @@
 import asyncio
-import logging
-import sys
+import json
+from logging import Logger
 from types import TracebackType
 from typing import Any, Literal, Optional, ClassVar
 
 import aiohttp
 from dotenv import load_dotenv
-from loguru import logger
 from tenacity import (
     retry,
     retry_if_exception_type,
@@ -28,6 +27,9 @@ from .exceptions import (
     APIServerError, APITooManyRequestsError,
 )
 
+from ...infrastructure import logging
+from ...infrastructure.logging import LoggingSettings
+
 
 class APIManager:
     """
@@ -44,14 +46,7 @@ class APIManager:
     _initialized: ClassVar[bool] = False
     _instance_count: ClassVar[int] = 0
 
-    _class_logger: ClassVar = logger
-    _class_logger.remove()
-    _class_logger.add(
-        sys.stderr,
-        level=APIConfig().log_level,
-        enqueue=True,
-    )
-
+    _class_logger: ClassVar[Logger] = APIConfig().logger
 
     def __init__(
             self,
@@ -70,36 +65,39 @@ class APIManager:
         self._config = self.load_config(config)
         self._client_id = client_id or self._config.client_id
         self._api_key = api_key or self._config.api_key
-        self._instance_id = id(self)
-        self._registered = False
-        self._closed = False
-        self._instance_logger = self._get_instance_logger()
 
         if self._client_id is None or self._api_key is None:
             raise ValueError(
                 "Не предоставлены авторизационные данные. Проверьте указание client_id и api_key."
             )
 
+        self._instance_id = id(self)
+        self._registered = False
+        self._closed = False
+        self._logging_manager = None
+        self._instance_logger: Logger = self._get_instance_logger()
+
+
         if APIManager._rate_limiter_manager is None:
             APIManager._rate_limiter_manager = RateLimiterManager(
                 cleanup_interval=self._config.cleanup_interval,
-                instance_logger=self.logger
+                instance_logger=logging.manager.get_logger(f"seller.rate_limiter")
             )
         if APIManager._session_manager is None:
             APIManager._session_manager = SessionManager(
                 timeout=self._config.request_timeout,
                 connector_limit=self._config.connector_limit,
-                instance_logger=self.logger
+                instance_logger=logging.manager.get_logger(f"seller.session")
             )
         if APIManager._method_rate_limiter_manager is None:
             APIManager._method_rate_limiter_manager = MethodRateLimiterManager(
                 cleanup_interval=self._config.cleanup_interval,
-                instance_logger=self.logger
+                instance_logger=logging.manager.get_logger(f"seller.method_rate_limiter")
             )
 
         APIManager._instance_count += 1
         self._validate_credentials()
-        self.logger.debug(f"API-клиент инициализирован для ClientID {self._client_id}")
+        self.logger.debug(f"API-клиент инициализирован")
 
     @classmethod
     def load_config(cls, user_config: APIConfig | None = None) -> APIConfig:
@@ -117,18 +115,38 @@ class APIManager:
                 )
             )
 
-    def _get_instance_logger(self) -> logging.Logger:
-        """Инициализирует и возвращает настроенный логер для экземпляра."""
-        instance_logger = logger.bind(client_id=self._client_id)
+    def _get_instance_logger(self) -> Logger:
+        """Инициализирует и возвращает настроенный логер для экземпляра.
 
-        instance_logger.remove()
-        instance_logger.add(
-            sys.stderr,
-            level=self._config.log_level,
-            enqueue=True,
-        )
+        Последнее значение `[x]` в домене обозначает порядковый номер активного
+        экземпляра менеджера для данного ClientID.
+        """
 
-        return instance_logger
+        log_instance_count = 1
+
+        while True:
+            self._logging_manager = logging.LoggerManager(
+                f"ozonapi.seller.client[{self._client_id}]-[{log_instance_count}]"
+            )
+
+            try:
+                self._logging_manager.configure(
+                    LoggingSettings(
+                        LEVEL=self._config.log_level,
+                        JSON=self._config.log_json,
+                        FORMAT=self._config.log_format,
+                        DIR=self._config.log_dir,
+                        FILE=self._config.log_file,
+                        MAX_BYTES=self._config.log_max_bytes,
+                        BACKUP_FILES_COUNT=self._config.log_backup_files_count,
+                    )
+                )
+            except RuntimeError:
+                log_instance_count += 1
+            else:
+                break
+
+        return self._logging_manager.get_logger()
 
     @classmethod
     async def initialize(cls) -> None:
@@ -214,7 +232,8 @@ class APIManager:
             if APIManager._session_manager:
                 await APIManager._session_manager.close_all()
 
-        self.logger.debug(f"Работа API-клиента для ClientID {self._client_id} завершена")
+        self.logger.debug(f"Работа API-клиента завершена")
+        self._logging_manager.shutdown()
 
     @property
     def client_id(self) -> str:
@@ -246,8 +265,7 @@ class APIManager:
 
         def log_retry(retry_state):
             self.logger.debug(
-                f"Попытка {retry_state.attempt_number} совершения запроса для ClientID {self._client_id}"
-                f" завершилась исключением: {retry_state.outcome.exception()}"
+                f"Попытка [{retry_state.attempt_number}/{self._config.max_retries}]. Запрос вернул ошибку: {retry_state.outcome.exception()}"
             )
 
         return retry(
@@ -265,7 +283,7 @@ class APIManager:
                 min=self._config.retry_min_wait,
                 max=self._config.retry_max_wait
             ),
-            before_sleep=before_sleep_log(self.logger, 30),
+            # before_sleep=before_sleep_log(self.logger, 30),
             after=log_retry,
             reraise=True,
         )
@@ -287,13 +305,7 @@ class APIManager:
         message = data.get("message", "Unknown error")
         details = data.get("details", [])
 
-        log_context.update({
-            "error_code": code,
-            "error_message": message,
-            "error_details": details,
-        })
-
-        APIManager._class_logger.error(f"Ошибка API: {message}", extra=log_context)
+        APIManager._class_logger.warning(f"Ошибка API: {message}")
 
         error_map = {
             400: APIClientError,
@@ -310,10 +322,9 @@ class APIManager:
     async def _request(
             self,
             method: Literal["post", "get", "put", "delete"] = "post",
-            api_name: str = "Ozon Seller API",
             api_version: str = "v1",
             endpoint: str = "",
-            json: Optional[dict[str, Any]] = None,
+            payload: Optional[dict[str, Any]] = None,
             params: Optional[dict[str, Any]] = None,
     ) -> dict[str, Any]:
         """
@@ -324,7 +335,7 @@ class APIManager:
             api_name: Название API
             api_version: Версия API
             endpoint: Конечная точка API
-            json: Данные для отправки в формате JSON
+            payload: Данные для отправки в формате JSON
             params: Query parameters
 
         Returns:
@@ -347,17 +358,22 @@ class APIManager:
 
         url = f"{self._config.base_url}/{api_version}/{endpoint}"
 
+        def get_payload_snippet(p: dict | None) -> str | None:
+            """Возвращает сниппет запроса для отладки."""
+            if p is None:
+                return None
+
+            string = json.dumps(payload)
+
+            return string if len(string) < 200 else string[:200] + "..."
+
         log_context = {
-            "api_name": api_name,
-            "client_id": self._client_id,
             "method": method,
-            "endpoint": endpoint,
-            "api_version": api_version,
-            "url": url,
-            "has_payload": json is not None,
+            "endpoint": f"{api_version}/{endpoint}",
+            "payload": get_payload_snippet(payload),
         }
 
-        self.logger.debug("Отправка запроса к API", extra=log_context)
+        self.logger.info(f"Отправка запроса к API: {log_context}")
 
         await self._ensure_registered()
 
@@ -378,7 +394,7 @@ class APIManager:
                 async with rate_limiter:
                     try:
                         async with session.request(
-                                method, url, json=json, params=params
+                                method, url, json=payload, params=params
                         ) as response:
                             data = await response.json()
 
@@ -387,19 +403,27 @@ class APIManager:
                                 "response_size": len(str(data))
                             })
 
+                            log_context_remove_keys = [
+                                'method', 'has_payload', 'payload'
+                            ]
+
+                            for key in log_context_remove_keys:
+                                if key in log_context:
+                                    del (log_context[key])
+
                             if response.status >= 400:
                                 error = self._handle_error_response(response, data, log_context)
                                 if error:
                                     raise error
 
-                            self.logger.debug("Успешный ответ от API", extra=log_context)
+                            self.logger.info(f"Получен ответ от API: {log_context}")
                             return data
 
                     except asyncio.TimeoutError:
-                        self.logger.error("Таймаут запроса к API", extra=log_context)
+                        self.logger.error("Таймаут запроса к API")
                         raise APIError(408, "Request timeout")
                     except asyncio.CancelledError:
-                        self.logger.warning("Запрос к API отменен", extra=log_context)
+                        self.logger.warning("Запрос к API отменен")
                         raise
                     except (aiohttp.ClientError, ConnectionError, OSError) as e:
                         log_context.update({
@@ -441,4 +465,4 @@ class APIManager:
         """Возвращает статистику по ограничителям методов."""
         if cls._method_rate_limiter_manager:
             return await cls._method_rate_limiter_manager.get_limiter_stats()
-        return dict()
\ No newline at end of file
+        return dict()
