@@ -3,6 +3,7 @@ __all__ = [
     "SellerBetaAPI",
     "SellerCategoryAPI",
     "SellerFBSAPI",
+    "SellerFBSAssemblyLabelingAPI",
     "SellerPricesAndStocksAPI",
     "SellerProductAPI",
     "SellerWarehouseAPI",
@@ -12,6 +13,7 @@ from .attributes_and_characteristics import SellerCategoryAPI
 from .barcodes import SellerBarcodeAPI
 from .beta import SellerBetaAPI
 from .fbs import SellerFBSAPI
+from .fbs_assembly_and_labeling import SellerFBSAssemblyLabelingAPI
 from .prices_and_stocks import SellerPricesAndStocksAPI
 from .products import SellerProductAPI
 from .warehouses import SellerWarehouseAPI
