@@ -30,6 +30,6 @@ class ProductImportInfoMixin(APIManager):
             method="post",
             api_version="v1",
             endpoint="product/import/info",
-            json=request.model_dump(),
+            payload=request.model_dump(),
         )
         return ProductImportInfoResponse(**response)
