@@ -3,6 +3,7 @@ __all__ = [
     "PostingFBSAnalyticsData",
     "PostingFBSBarcodes",
     "PostingFBSCancellation",
+    "PostingFBSCancelReason",
     "PostingFBSCustomer",
     "PostingFBSCustomerAddress",
     "PostingFBSDeliveryMethod",
@@ -12,6 +13,7 @@ __all__ = [
     "PostingFBSOptional",
     "PostingFBSPosting",
     "PostingFBSProduct",
+    "PostingFBSProductWithCurrencyCode",
     "PostingFBSProductDetailed",
     "PostingFBSRequirements",
     "PostingFBSTariffication",
@@ -20,6 +22,7 @@ __all__ = [
 
 from .posting__analytics_data import PostingFBSAnalyticsData
 from .posting__barcodes import PostingFBSBarcodes
+from .posting__cancel_reason import PostingFBSCancelReason
 from .posting__cancellation import PostingFBSCancellation
 from .posting__customer import PostingFBSCustomer
 from .posting__customer_address import PostingFBSCustomerAddress
@@ -30,7 +33,7 @@ from .posting__financial_data_products import PostingFBSFinancialDataProducts
 from .posting__legal_info import PostingFBSLegalInfo
 from .posting__optional import PostingFBSOptional
 from .posting__posting import PostingFBSPosting
-from .posting__product import PostingFBSProductDetailed, PostingFBSProduct
+from .posting__product import PostingFBSProductDetailed, PostingFBSProduct, PostingFBSProductWithCurrencyCode
 from .posting__requirements import PostingFBSRequirements
 from .posting__tariffication import PostingFBSTariffication
 from .posting__addressee import PostingFBSAddressee
\ No newline at end of file
